#
# K2HDKC DBaaS Command Line Interface - K2HR3 CLI Plugin
#
# Copyright 2021 Yahoo Japan Corporation.
#
# K2HDKC DBaaS is a DataBase as a Service provided by Yahoo! JAPAN
# which is built K2HR3 as a backend and provides services in
# cooperation with OpenStack.
# The Override configuration for K2HDKC DBaaS serves to connect the
# components that make up the K2HDKC DBaaS. K2HDKC, K2HR3, CHMPX,
# and K2HASH are components provided as AntPickax.
#
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Mon Mar 1 2021
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.9

%if %{undefined make_check}
%global make_check 1
%endif

%if %{undefined not_run_autogen}
%global run_autogen ./autogen.sh
%else
%global run_autogen echo "skip autogen.sh"
%endif

#
# main package
#
Summary: K2HDKC DBaaS Command Line Interface
Name: k2hdkc-dbaas-cli
Version: 1.0.9
Release: %{package_revision}%{?dist}
License: MIT
Group: Applications/Other
URL: https://github.com/yahoojapan/k2hdkc-dbaas-cli
Source0: https://github.com/yahoojapan/k2hdkc-dbaas-cli/archive/%{gittag}/%{name}-%{version}.tar.gz
Requires: k2hr3-cli
BuildRequires: git-core make
BuildArch: noarch

%description
The K2HDKC DBaaS CLI (Command Line Interface of Database as a
Service for K2HDKC) is a tool for building a K2HDKC cluster
in conjunction with K2HR3.
The Trove version of K2HDKC DBaaS is available, but this
K2HDKC DBaaS CLI allows you to build K2HDKC clusters without
the need for a Trove system.
With the basic components of OpenStack and the K2HR3 system
that works with it, you can easily build a K2HD KC cluster
using the K2HDKC DBaaS CLI.

%prep
%autosetup -n %{name}-%{version}

%build
%run_autogen
%configure --disable-static 
make build

%install
%make_install
install -D -m 444 src/libexec/database/CREDIT                            %{buildroot}/usr/libexec/k2hr3/database/CREDIT
install -D -m 444 src/libexec/database/VERSION                           %{buildroot}/usr/libexec/k2hr3/database/VERSION
install -D -m 444 src/libexec/database/k2hdkc_dbaas_create_host.templ    %{buildroot}/usr/libexec/k2hr3/database/k2hdkc_dbaas_create_host.templ
install -D -m 444 src/libexec/database/k2hdkc_dbaas_resource_keys.config %{buildroot}/usr/libexec/k2hr3/database/k2hdkc_dbaas_resource_keys.config
install -D -m 444 src/libexec/database/k2hdkc_dbaas_resource.templ       %{buildroot}/usr/libexec/k2hr3/database/k2hdkc_dbaas_resource.templ
install -D -m 444 src/libexec/database/command.sh                        %{buildroot}/usr/libexec/k2hr3/database/command.sh
install -D -m 444 src/libexec/database/functions.sh                      %{buildroot}/usr/libexec/k2hr3/database/functions.sh
install -D -m 444 src/libexec/database/help.sh                           %{buildroot}/usr/libexec/k2hr3/database/help.sh
install -D -m 444 src/libexec/database/openstack.sh                      %{buildroot}/usr/libexec/k2hr3/database/openstack.sh
install -D -m 444 src/libexec/database/options.sh                        %{buildroot}/usr/libexec/k2hr3/database/options.sh
install -D -m 444 src/libexec/database/summary.sh                        %{buildroot}/usr/libexec/k2hr3/database/summary.sh
install -D -m 444 src/libexec/database/variables.sh                      %{buildroot}/usr/libexec/k2hr3/database/variables.sh

%if %{make_check}
%check
%{__make} check
%endif

%files
%license COPYING
%doc README AUTHORS ChangeLog
/usr/libexec/k2hr3/database/*

%changelog
* Tue Oct 31 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.9-1
- Changed support OS (fedora and ubuntu) and updated tool - #31

* Fri Sep 01 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.8
- Updated tool scripts and support OSs #29
- Fixed .gitignore to exclude APKBUILD.templ - #28

* Fri Jul 28 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.7
- Changed due to k2hr3cli insecure communication support - #26

* Mon Mar 06 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.6
- Updated building/packaging scripts - #24

* Thu Feb 16 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.5
- Fixed Makefile.am and PKBUILD.templ.in in buildutils - #22

* Wed Feb 15 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.4
- Changed CI OSs and added Alpine OS - #20
- Updated header and footer in comment lines - #19
- Updated issue/pullrequest templates and README.md - #18
- Reviewed ShellCheck processing and updated .gitignore - #17
- Reviewed ShellCheck processing and fixed bugs - #16
- Eliminated unnecessary copies in build_helper.sh - #15
- Updated github actions process and support os, and fixed bugs - #14
- Updated debian_build.sh for grep parameter and updated configure.ac - #13
- Updated common build scripts - #12
- Updated buld tools(Makefile.am and build_helper.sh) - #11
- Separated the shellcheck process in the build process - #10
- Updated Antpickax common scripts and tools under the buildutils directory - #9
- Enabled external customization of configure.ac and fixed for building - #8

* Thu Sep 30 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.3
- Updated README.md for launch K2HDKC DBaaS K8S CLI - #6

* Thu Apr 08 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.2
- Added an option to specify a block device when launching VM - #4

* Wed Apr 07 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.1
- Fixed to check the interface type of OpenStack Service endpoints - #2
- Updated interactive logic for values about OpenStack user... - #1

* Mon Mar 22 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.0
- First version
